@@ -1,5 +1,6 @@
 from nonebot.adapters.onebot.v11 import GroupMessageEvent, Message, MessageSegment, Bot
 from typing import Optional, Tuple, Union, List, Dict
+from datetime import datetime
 from nonebot.log import logger
 from pathlib import Path
 import nonebot
@@ -510,7 +511,7 @@ class RussianManager:
                 "lose_gold": 0,
                 "win_count": 0,
                 "lose_count": 0,
-                "is_sign": False,
+                "is_sign": None,
             }
 
     async def end_game(self, bot: Bot, event: GroupMessageEvent):
